fnss.adapters.omnetpp.to_omnetpp — FNSS 0.6.1 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »

# fnss.adapters.omnetpp.to_omnetpp

`to_omnetpp`(topology, path=None)

  Convert an FNSS topology into an Omnet++ NED script.

  Parameters: | topology : Topology The topology object to convert path : str, optional The path to the output NED file. If not specified, prints to standard output

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.6.1 documentation »
- API Reference »
- Functions »